@@ -6,21 +6,20 @@ from airflow.exceptions import AirflowException
 from airflow.utils.state import State
 from dagster_airflow.vendor.kubernetes_pod_operator import KubernetesPodOperator
 from dagster_graphql.client.query import RAW_EXECUTE_PLAN_MUTATION
+from dagster_graphql.client.util import construct_variables, parse_raw_log_lines
 
 from dagster import __version__ as dagster_version
-from dagster import check, seven
-from dagster.core.definitions.pipeline import ExecutionSelector
+from dagster import seven
 from dagster.core.events import EngineEventData
-from dagster.core.instance import DagsterInstance, InstanceRef
-from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
+from dagster.core.instance import DagsterInstance
+from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.utils.error import serializable_error_info_from_exc_info
 
 from .util import (
+    add_airflow_tags,
     check_events_for_failures,
     check_events_for_skips,
-    construct_variables,
     get_aws_environment,
-    parse_raw_res,
 )
 
 # For retries on log retrieval
@@ -36,55 +35,28 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
 
     # py2 compat
     # pylint: disable=keyword-arg-before-vararg
-    def __init__(
-        self,
-        task_id,
-        environment_dict=None,
-        pipeline_name=None,
-        mode=None,
-        step_keys=None,
-        dag=None,
-        instance_ref=None,
-        *args,
-        **kwargs
-    ):
-        check.str_param(pipeline_name, 'pipeline_name')
-        step_keys = check.opt_list_param(step_keys, 'step_keys', of_type=str)
-        environment_dict = check.opt_dict_param(environment_dict, 'environment_dict', key_type=str)
-        check.opt_inst_param(instance_ref, 'instance_ref', InstanceRef)
-
+    def __init__(self, operator_parameters, *args):
+        kwargs = operator_parameters.op_kwargs
+        self.pipeline_name = operator_parameters.pipeline_name
+        self.pipeline_snapshot = operator_parameters.pipeline_snapshot
+        self.execution_plan_snapshot = operator_parameters.execution_plan_snapshot
         kwargs['name'] = 'dagster.{pipeline_name}.{task_id}'.format(
-            pipeline_name=pipeline_name, task_id=task_id
+            pipeline_name=self.pipeline_name, task_id=operator_parameters.task_id
         ).replace(
             '_', '-'  # underscores are not permissible DNS names
         )
 
-        if 'storage' not in environment_dict:
-            raise AirflowException(
-                'No storage config found -- must configure either filesystem or s3 storage for '
-                'the DagsterKubernetesPodOperator. Ex.: \n'
-                'storage:\n'
-                '  filesystem:\n'
-                '    base_dir: \'/some/shared/volume/mount/special_place\''
-                '\n\n --or--\n\n'
-                'storage:\n'
-                '  s3:\n'
-                '    s3_bucket: \'my-s3-bucket\'\n'
-            )
-
-        check.invariant(
-            'in_memory' not in environment_dict.get('storage', {}),
-            'Cannot use in-memory storage with Airflow, must use S3',
-        )
-
-        self.environment_dict = environment_dict
-        self.pipeline_name = pipeline_name
-        self.mode = mode
-        self.step_keys = step_keys
+        self.environment_dict = operator_parameters.environment_dict
+        self.mode = operator_parameters.mode
+        self.step_keys = operator_parameters.step_keys
         self._run_id = None
         # self.instance might be None in, for instance, a unit test setting where the operator
         # was being directly instantiated without passing through make_airflow_dag
-        self.instance = DagsterInstance.from_ref(instance_ref) if instance_ref else None
+        self.instance = (
+            DagsterInstance.from_ref(operator_parameters.instance_ref)
+            if operator_parameters.instance_ref
+            else None
+        )
 
         # Store Airflow DAG run timestamp so that we can pass along via execution metadata
         self.airflow_ts = kwargs.get('ts')
@@ -112,7 +84,7 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
         kwargs['xcom_push'] = False
 
         super(DagsterKubernetesPodOperator, self).__init__(
-            task_id=task_id, dag=dag, *args, **kwargs
+            task_id=operator_parameters.task_id, dag=operator_parameters.dag, *args, **kwargs
         )
 
     @property
@@ -121,23 +93,15 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
 
     @property
     def query(self):
-        # TODO: https://github.com/dagster-io/dagster/issues/1342
-        redacted = construct_variables(
-            self.mode, 'REDACTED', self.pipeline_name, self.run_id, self.airflow_ts, self.step_keys
+        variables = construct_variables(
+            self.mode, self.environment_dict, self.pipeline_name, self.run_id, self.step_keys,
         )
+        variables = add_airflow_tags(variables, self.airflow_ts)
+
         self.log.info(
             'Executing GraphQL query: {query}\n'.format(query=RAW_EXECUTE_PLAN_MUTATION)
             + 'with variables:\n'
-            + seven.json.dumps(redacted, indent=2)
-        )
-
-        variables = construct_variables(
-            self.mode,
-            self.environment_dict,
-            self.pipeline_name,
-            self.run_id,
-            self.airflow_ts,
-            self.step_keys,
+            + seven.json.dumps(variables, indent=2)
         )
 
         return [
@@ -205,19 +169,19 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
             pod.security_context = self.security_context
 
             launcher = pod_launcher.PodLauncher(kube_client=client, extract_xcom=self.xcom_push)
-            pipeline_run = PipelineRun(
-                pipeline_name=self.pipeline_name,
-                run_id=self.run_id,
-                environment_dict=self.environment_dict,
-                mode=self.mode,
-                selector=ExecutionSelector(self.pipeline_name),
-                step_keys_to_execute=None,
-                tags=None,
-                status=PipelineRunStatus.MANAGED,
-            )
             try:
                 if self.instance:
-                    self.instance.get_or_create_run(pipeline_run)
+                    run = self.instance.get_or_create_run(
+                        pipeline_name=self.pipeline_name,
+                        run_id=self.run_id,
+                        environment_dict=self.environment_dict,
+                        mode=self.mode,
+                        step_keys_to_execute=None,
+                        tags=None,
+                        status=PipelineRunStatus.MANAGED,
+                        pipeline_snapshot=self.pipeline_snapshot,
+                        execution_plan_snapshot=self.execution_plan_snapshot,
+                    )
 
                 # we won't use the "result", which is the pod's xcom json file
                 (final_state, _) = launcher.run_pod(
@@ -233,22 +197,20 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
                     raw_res = client.read_namespaced_pod_log(
                         name=pod.name, namespace=pod.namespace, container='base'
                     )
-                    res = parse_raw_res(raw_res.split('\n'))
+                    res = parse_raw_log_lines(raw_res.split('\n'))
                     time.sleep(LOG_RETRIEVAL_WAITS_BETWEEN_ATTEMPTS_SEC)
                     num_attempts += 1
-                    self.log.debug('k8s pod raw response: ' + str(raw_res))
-                    self.log.debug('parsed response: ' + str(res))
 
                 try:
                     handle_execution_errors(res, 'executePlan')
                 except DagsterGraphQLClientError as err:
                     self.instance.report_engine_event(
-                        self.__class__,
                         str(err),
-                        pipeline_run,
+                        run,
                         EngineEventData.engine_error(
                             serializable_error_info_from_exc_info(sys.exc_info())
                         ),
+                        self.__class__,
                     )
                     raise
 
